Learn R Programming

hassediagrams (version 1.0)

analytical: A cross-nested design for an analytical method investigation

Description

The reliability of an analytical method was assessed in an experiment consisting of three batches of material, analysed by four analysts, two at each site. Within each site, there were two chromatographic systems and two columns. For each batch/analyst/system/column combination, two preparations (dissolved samples) were made. From each preparation, two injections were performed.

Usage

data(analytical)

Arguments

Format

A data frame of 192 observations on 8 variables/factors:

Site

Categoric factor with levels 1 and 2.

Analyst

Categoric factor with levels 1-4.

Run

Categoric factor with levels 1-16.

Prep

Categoric factor with levels 1-96.

Injection

Categoric factor with levels 1-192.

System

Categoric factor with levels 1-4.

Column

Categoric factor with levels 1-4.

Batch

Categoric factor with levels 1-3.

Examples

Run this code
data("analytical")
analytical

Run the code above in your browser using DataLab