Learn R Programming

hassediagrams (version 1.0)

dental: A crossover design for a dental study

Description

This is a crossover design (Study H) given in Newcombe et al. (1995) to study the effects of CHX rinses on 4 day plaque regrowth. The study consisted of 24 patients assessed over 3 treatment periods. The purpose of the study was to compare 2 CHX rinses with saline. The design is based on pairs of Latin squares balanced for carry over.

Usage

data(dental)

Arguments

Format

A crossover design of 72 runs on 5 variables/factors. The 5 variables/factors included in the design are:

Sequence

Categoric factor with levels 1-6.

Subject

Categoric factor with levels 1-32.

Period

Categoric factor with levels 1-3.

Treatment

Categoric factor with levels CHX1, CHX2 and Saline.

Observation

Categoric factor with levels 1-72.

Examples

Run this code
data("dental")
dental

Run the code above in your browser using DataLab