Learn R Programming

hassediagrams (version 1.0)

hassediagrams-package: hassediagrams: Hasse Diagram of the Layout Structure and Restricted Layout Structure

Description

Returns a Hasse diagram of the layout structure (Bate and Chatfield (2016)) tools:::Rd_expr_doi("10.1080/00224065.2016.11918173") or the restricted layout structure (Bate and Chatfield (2016)) tools:::Rd_expr_doi("10.1080/00224065.2016.11918174") of an experimental design.

Arguments

Author

Maintainer: Damianos Michaelides dm3g15@soton.ac.uk

Authors:

See Also