# \donttest{
## Examples using the package build-in data concrete, dental, human, analytical.
## A fractional factorial design for investigating asphalt concrete production
hasselayout(datadesign=concrete, larger.fontlabelmultiplier=1.6,
smaller.fontlabelmultiplier=1.3, table.out="Y")
## A crossover design for a dental study
hasselayout(datadesign=dental, randomfacsid = c(0,1,0,0,0),
larger.fontlabelmultiplier = 1.6)
## A block design for an experiment assessing human-computer interaction
hasselayout(datadesign=human, randomfacsid = c(1,1,0,0,0,0,1),
larger.fontlabelmultiplier=1.4)
## A cross-nested design for an analytical method investigation
hasselayout(datadesign=analytical, randomfacsid = c(0,0,1,1,1,0,0,0),
showpartialLS="N", check.confound.df="N",
larger.fontlabelmultiplier=1,
smaller.fontlabelmultiplier=1.6)
## Examples using data from the dae package (conditionally loaded)
if (requireNamespace("dae", quietly = TRUE)) {
## Data for a balanced incomplete block experiment, Joshi (1987)
data(BIBDWheat.dat, package = "dae")
# remove the response from the dataset
BIBDWheat <- BIBDWheat.dat[, -4]
hasselayout(datadesign=BIBDWheat, example = "BIBDWheat")
## Data for an un-replicated 2^4 factorial experiment to investigate a chemical process
## from Table 10.6 of Box, Hunter and Hunter (1978)
data(Fac4Proc.dat, package = "dae")
# remove the response from the dataset
Fac4Proc <- Fac4Proc.dat[, -6]
hasselayout(datadesign=Fac4Proc, example = "Fac4Proc", showpartialLS="N",
smaller.fontlabelmultiplier=2)
## Data for an experiment with rows and columns from p.144 of
## Williams, Matheson and Harwood (2002)
data(Casuarina.dat, package = "dae")
# remove the response from the dataset
Casuarina <- Casuarina.dat[, -7]
# create unique factor level labels
Casuarina$Row <- paste(Casuarina$Reps, Casuarina$Rows)
Casuarina$Col <- paste(Casuarina$Reps, Casuarina$Columns)
Casuarina <- Casuarina[, -c(2,3)]
hasselayout(datadesign=Casuarina, randomfacsid=c(1,0,1,0,0,0),
example="Casuarina", check.confound.df="N",
showpartialLS="N")
} else {
message("Examples using data from the 'dae' package
require 'dae' to be installed.")
}
# }
Run the code above in your browser using DataLab