Learn R Programming

hassediagrams (version 1.0)

print.rls: Print and Summary of rls objects

Description

Print and Summary of objects of class "rls".

Usage

# S3 method for rls
print(x, ...)

# S3 method for rls summary(object, ...)

Value

The functions return the structural objects of the Layout Structure and a matrix that the users need to edit with the randomisation objects to pass in the hasserls function.

Arguments

x

An object of class "rls".

...

Additional arguments to be passed to other methods.

object

An object of class "rls".

Author

Damianos Michaelides, Simon Bate, and Marion Chatfield