rls objectsPrint and Summary of objects of class "rls".
# S3 method for rls
print(x, ...)# S3 method for rls
summary(object, ...)
The functions return the structural objects of the Layout Structure
and a matrix that the users need to edit with the randomisation
objects to pass in the hasserls function.
An object of class "rls".
Additional arguments to be passed to other methods.
An object of class "rls".
Damianos Michaelides, Simon Bate, and Marion Chatfield